package com.jsh.erp.controller.pda;

import com.jsh.erp.base.AjaxResult;
import com.jsh.erp.base.BaseController;
import com.jsh.erp.base.TableDataInfo;
import com.jsh.erp.datasource.dto.DepotHeadDTO;
import com.jsh.erp.datasource.entities.DepotHead;
import com.jsh.erp.datasource.entities.DepotItem;
import com.jsh.erp.query.LambdaQueryWrapperX;
import com.jsh.erp.service.DepotHeadService;
import com.jsh.erp.service.DepotItemService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

@RestController
@RequestMapping(value = "/pda")
@Api(tags = {"PDA接口"})
public class PdaController extends BaseController {

    @Resource
    private DepotHeadService depotHeadService;

    private DepotItemService depotItemService;

    /**
     * 采购入库
     * @return
     */
    @PostMapping ("/purchaseInventory")
    @ApiOperation(value = "采购入库")
    public TableDataInfo purchaseInventory(@RequestBody DepotHeadDTO depotHeadDTO) {
        startPage();
        List<DepotHead> list = depotHeadService.list(new LambdaQueryWrapperX<DepotHead>()
                .eq(DepotHead::getSubType, "采购订单")
                .eqIfPresent(DepotHead::getNumber, depotHeadDTO.getNumber())
                .betweenIfPresent(DepotHead::getCreateTime, depotHeadDTO.getBeginTime(), depotHeadDTO.getEndTime())
                .eqIfPresent(DepotHead::getStatus, depotHeadDTO.getStatus())
//                .eq(DepotHead::getStatus, "1")
        );
        return getDataTable(list);
    }

    @PostMapping("/saleOrder")
    @ApiOperation(value = "检货任务")
    public TableDataInfo saleOrder(@RequestBody DepotHeadDTO depotHeadDTO) {
        startPage();
        List<DepotHead> list = depotHeadService.list(new LambdaQueryWrapperX<DepotHead>()
                .eq(DepotHead::getSubType, "销售订单")
                .eqIfPresent(DepotHead::getNumber, depotHeadDTO.getNumber())
                .betweenIfPresent(DepotHead::getCreateTime, depotHeadDTO.getBeginTime(), depotHeadDTO.getEndTime())
                .eqIfPresent(DepotHead::getStatus, depotHeadDTO.getStatus())
//                .eq(DepotHead::getStatus, "1")
        );
        return getDataTable(list);
    }

    @GetMapping("/orderDetail/{id}")
    @ApiOperation("订单明细")
    public TableDataInfo orderDetail(@PathVariable("id") Long id) {
        startPage();
        List<DepotItem> list = depotItemService.list(new LambdaQueryWrapperX<DepotItem>().eq(DepotItem::getHeaderId, id));
        return getDataTable(list);
    }



}
